@@ -12,10 +12,6 @@
 #include <algorithm>
 #include <boost/algorithm/string.hpp>
 #include <boost/algorithm/string/predicate.hpp>
-#include <boost/format.hpp>
-#include <boost/iostreams/device/file_descriptor.hpp>
-#include <boost/iostreams/stream.hpp>
-#include <boost/iostreams/stream_buffer.hpp>
 #include <cstddef>
 #include <cstdint>
 #include <exception>
@@ -24,12 +20,13 @@
 #include <fcitx-utils/charutils.h>
 #include <fcitx-utils/event.h>
 #include <fcitx-utils/eventloopinterface.h>
+#include <fcitx-utils/fdstreambuf.h>
 #include <fcitx-utils/i18n.h>
 #include <fcitx-utils/key.h>
 #include <fcitx-utils/keysym.h>
 #include <fcitx-utils/log.h>
 #include <fcitx-utils/macros.h>
-#include <fcitx-utils/standardpath.h>
+#include <fcitx-utils/standardpaths.h>
 #include <fcitx-utils/stringutils.h>
 #include <fcitx-utils/textformatflags.h>
 #include <fcitx-utils/utf8.h>
@@ -47,7 +44,6 @@
 #include <fcitx/userinterface.h>
 #include <fcitx/userinterfacemanager.h>
 #include <fcntl.h>
-#include <fmt/format.h>
 #include <istream>
 #include <libime/core/historybigram.h>
 #include <libime/core/languagemodel.h>
@@ -122,7 +118,7 @@ public:
         if (py.empty()) {
             setText(Text(hz_));
         } else {
-            setText(Text(fmt::format(_("{0} ({1})"), hz_, py)));
+            setText(Text(_("{0} ({1})", hz_, py)));
         }
     }
 
@@ -361,14 +357,11 @@ JyutpingEngine::JyutpingEngine(Instance *instance)
             libime::DefaultLanguageModelResolver::instance()
                 .languageModelFileForLanguage("zh_HK")));
 
-    const auto &standardPath = StandardPath::global();
-    auto systemDictFile = standardPath.open(StandardPath::Type::Data,
-                                            "libime/jyutping.dict", O_RDONLY);
+    const auto &standardPath = StandardPaths::global();
+    auto systemDictFile =
+        standardPath.open(StandardPathsType::Data, "libime/jyutping.dict");
     if (systemDictFile.isValid()) {
-        boost::iostreams::stream_buffer<
-            boost::iostreams::file_descriptor_source>
-            buffer(systemDictFile.fd(),
-                   boost::iostreams::file_descriptor_flags::never_close_handle);
+        IFDStreamBuf buffer(systemDictFile.fd());
         std::istream in(&buffer);
         ime_->dict()->load(libime::jyutping::JyutpingDictionary::SystemDict, in,
                            libime::jyutping::JyutpingDictFormat::Binary);
@@ -380,18 +373,16 @@ JyutpingEngine::JyutpingEngine(Instance *instance)
     prediction_.setUserLanguageModel(ime_->model());
 
     do {
-        auto file = standardPath.openUser(StandardPath::Type::PkgData,
-                                          "jyutping/user.dict", O_RDONLY);
+        auto file =
+            standardPath.open(StandardPathsType::PkgData, "jyutping/user.dict",
+                              StandardPathsMode::User);
 
         if (file.fd() < 0) {
             break;
         }
 
         try {
-            boost::iostreams::stream_buffer<
-                boost::iostreams::file_descriptor_source>
-                buffer(file.fd(), boost::iostreams::file_descriptor_flags::
-                                      never_close_handle);
+            IFDStreamBuf buffer(file.fd());
             std::istream in(&buffer);
             ime_->dict()->load(libime::jyutping::JyutpingDictionary::UserDict,
                                in,
@@ -400,14 +391,12 @@ JyutpingEngine::JyutpingEngine(Instance *instance)
         }
     } while (0);
     do {
-        auto file = standardPath.openUser(StandardPath::Type::PkgData,
-                                          "jyutping/user.history", O_RDONLY);
+        auto file =
+            standardPath.open(StandardPathsType::PkgData,
+                              "jyutping/user.history", StandardPathsMode::User);
 
         try {
-            boost::iostreams::stream_buffer<
-                boost::iostreams::file_descriptor_source>
-                buffer(file.fd(), boost::iostreams::file_descriptor_flags::
-                                      never_close_handle);
+            IFDStreamBuf buffer(file.fd());
             std::istream in(&buffer);
             ime_->model()->load(in);
         } catch (const std::exception &) {
@@ -697,14 +686,12 @@ void JyutpingEngine::keyEvent(const InputMethodEntry &entry, KeyEvent &event) {
                 std::string text;
                 if (!output.empty()) {
                     if (!altOutput.empty()) {
-                        text = boost::str(
-                            boost::format(
-                                _("Press %1% for %2% and %3% for %4%")) %
-                            keyString % output % _("Return") % altOutput);
-                    } else {
                         text =
-                            boost::str(boost::format(_("Press %1% for %2%")) %
-                                       keyString % altOutput);
+
+                            _("Press {0} for {1} and {2} for {3}", keyString,
+                              output, _("Return"), altOutput);
+                    } else {
+                        text = _("Press {0} for {1}", keyString, altOutput);
                     }
                 }
                 quickphrase()->call<IQuickPhrase::trigger>(
@@ -744,13 +731,10 @@ void JyutpingEngine::doReset(InputContext *inputContext) {
 
 void JyutpingEngine::save() {
     safeSaveAsIni(config_, "conf/jyutping.conf");
-    const auto &standardPath = StandardPath::global();
+    const auto &standardPath = StandardPaths::global();
     standardPath.safeSave(
-        StandardPath::Type::PkgData, "jyutping/user.dict", [this](int fd) {
-            boost::iostreams::stream_buffer<
-                boost::iostreams::file_descriptor_sink>
-                buffer(fd, boost::iostreams::file_descriptor_flags::
-                               never_close_handle);
+        StandardPathsType::PkgData, "jyutping/user.dict", [this](int fd) {
+            OFDStreamBuf buffer(fd);
             std::ostream out(&buffer);
             try {
                 ime_->dict()->save(
@@ -761,20 +745,17 @@ void JyutpingEngine::save() {
                 return false;
             }
         });
-    standardPath.safeSave(
-        StandardPath::Type::PkgData, "jyutping/user.history", [this](int fd) {
-            boost::iostreams::stream_buffer<
-                boost::iostreams::file_descriptor_sink>
-                buffer(fd, boost::iostreams::file_descriptor_flags::
-                               never_close_handle);
-            std::ostream out(&buffer);
-            try {
-                ime_->model()->save(out);
-                return true;
-            } catch (const std::exception &) {
-                return false;
-            }
-        });
+    standardPath.safeSave(StandardPathsType::PkgData, "jyutping/user.history",
+                          [this](int fd) {
+                              OFDStreamBuf buffer(fd);
+                              std::ostream out(&buffer);
+                              try {
+                                  ime_->model()->save(out);
+                                  return true;
+                              } catch (const std::exception &) {
+                                  return false;
+                              }
+                          });
 }
 } // namespace fcitx
 
